import classnames from 'classnames';

import Placeholder from './Placeholder';

import useIsObserved from './hooks/useIsObserved';
import useMountAd from './hooks/useMountAd';
import useMountOnObserve from './hooks/useMountOnObserve';

import stylesheet from './styles.module.scss';

const Ad = props => {
  const { type, classes } = props;

  const {
    container: containerClass,
    root: rootClass,
    disclaimer: disclaimerClass,
  } = classes;

  const [ref, observed] = useIsObserved();
  const [id, mountAd] = useMountAd(type);

  const isMounted = useMountOnObserve({ observed, mountAd });

  return (
    <div ref={ref} className={classnames('PibAd-container', 'content-group', 'screenshot-remove', containerClass)}>
      <p className={classnames('PibAd-disclaimer', disclaimerClass)}>
        Advertisement
      </p>
      <Placeholder active={!isMounted} type={type} />
      <div id={id} className={classnames('PibAd-root', 'ad-slot', 'flex', 'horizontal', rootClass)} />
      <style jsx>{stylesheet}</style>
    </div>
  );
};

Ad.defaultProps = {
  type: 'supercube',
  classes: {},
};

export default Ad;
