import { useState, useEffect, useMemo } from 'react';
import { formatToTimeZone } from 'date-fns-timezone';

export default function useLocalTime(time, defaultTimezone = 'America/New_York') {
  const [timezone, updateTimezone] = useState(defaultTimezone);

  useEffect(() => {
    try {
      const timezone = Intl.DateTimeFormat().resolvedOptions().timeZone;
      updateTimezone(timezone);
    } catch (e) {}
  }, []);

  return useMemo(() => {
    if (!time) {
      return '';
    }

    const timeDate = new Date(time);
    const formatString = timeDate.getMinutes() === 0 ? 'h A z' : 'h:mm A z';
    return formatToTimeZone(timeDate, formatString, { timeZone: timezone });
  }, [timezone, time]);
}
