import classnames from 'classnames';

import useBylines from './hooks/useBylines';
import useLocalTime from './hooks/useLocalTime';

import stylesheet from './styles.module.scss';

const Info = props => {
  const {
    authors,
    published,
    updated,
    classes,
    defaultTimezone,
  } = props;
  const noMargins = props['no-margins'];

  const {
    container: containerClass,
    root: rootClass,
    authorsContainer: authorsClass,
    published: publishedClass,
    updated: updatedClass,
    timestamp: timestampClass,
  } = classes;

  const byline = useBylines(authors, classes);
  const publishedFormatted = useLocalTime(published, defaultTimezone);
  const updatedFormatted = useLocalTime(updated, defaultTimezone);

  return (
    <div className={classnames('PibInfo-container', containerClass, { 'no-margins': noMargins })}>
      <p className={classnames('PibInfo-root', rootClass)}>
        {authors && authors.length > 0 &&
          <span
            className={classnames('PibInfo-authors', authorsClass)}
          >
           By {byline}
          </span>
        }

        {/* Published & Updated Element */}
        {published && updated &&
          <span
            className={classnames('PibInfo-published', publishedClass)}
          >
            {' | '}
            {publishedFormatted}
          </span>
        }
        {updated &&
          <span
            className={classnames('PibInfo-updated', updatedClass)}
          >
            {' | '}
            <time dateTime={updated}>Updated {updatedFormatted}</time>
          </span>
        }

        {/* Else Published Element */}
        {published && !updated &&
          <span
            className={classnames('PibInfo-published', publishedClass)}
          >
            {' | '}
            <time
              className={classnames('PibInfo-timestamp', timestampClass)}
              dateTime={published}>{publishedFormatted}
            </time>
          </span>
        }
      </p>
      <style jsx>{stylesheet}</style>
    </div>
  );
};

Info.defaultProps = {
  authors: [],
  published: null,
  updated: null,
  defaultTimezone: 'America/New_York',
  classes: {},
};

export default Info;
