import classnames from 'classnames';

import stylesheet from './styles.module.scss';

const defaultThemes = {
  magazine: 'dark',
  default: 'light',
};

const Navigation = props => {
  const { classes } = props;
  const site = props.site.toLowerCase();
  const theme = props.theme || defaultThemes[site] || defaultThemes.default;

  const {
    container: containerClass,
    root: rootClass,
    branding: brandingClass,
    home: homeClass,
    links: linksClass,
  } = classes;

  return (
    <nav
      title='navigation'
      className={classnames('PibNavigation-container', 'navigation', 'global', containerClass)}
    >
      <div
        id='global-header'
        className={classnames('PibNavigation-root', rootClass, {
          magazine: site === 'magazine',
          dark: theme === 'dark',
          light: theme === 'light',
        })}
      >
        <div id='header-contents' className='header-contents'>
          <div id='global-branding' className={classnames('PibNavigation-branding', brandingClass)}>
            {site === 'magazine' && (
              <a
                className='navbar-brand'
                href='https://www.politico.com/magazine/'
                title='POLITICO'
                target='_top'
              >
                <span className='bt-icon bt-icon--politico' />
                <span className='bt-icon bt-icon--magazine' />
              </a>
            )}
            {site !== 'magazine' && (
              <a
                className='navbar-brand'
                href='https://www.politico.com/'
                title='POLITICO'
                target='_top'
              >
                <span className='bt-icon bt-icon--politico' />
              </a>
            )}
          </div>

          <nav id='nav-micro'>
            <div className={classnames('PibNavigation-home', 'header-content', homeClass)}>
              <div className='header-left'>
                <a href='https://www.politico.com'>
                  <svg
                    xmlns='http://www.w3.org/2000/svg'
                    height='20px'
                    version='1.1'
                    x='0px'
                    y='0px'
                    viewBox='0 0 100 100'
                    enableBackground='new 0 0 100 100'
                    xmlSpace='preserve'
                  >
                    <path d='M79.5,81.458h-57V41.27L51,16.729L79.5,41.27V81.458z M25.5,78.458h51V42.646L51,20.688L25.5,42.646V78.458z' />
                  </svg>
                </a>
              </div>

              <div className={classnames('PibNavigation-links', 'header-right', linksClass)}>
                <ul className='micro-list'>
                  {site !== 'magazine' && (
                    <li className='subnav d-none d-sm-block'>
                      <a
                        href='https://www.politico.com/magazine/'
                        target='_top'
                      >
                          Mag<span className='d-sm-none d-md-none'>azine</span>
                      </a>
                    </li>
                  )}
                  <li className='subnav d-none d-sm-block'>
                    <a href='https://www.politico.com/agenda/' target='_top'>
                      <span className='d-sm-none'>The</span> Agenda
                    </a>
                  </li>
                  <li className='subnav'>
                    <a href='https://www.politicopro.com' target='_top'>
                        PRO
                    </a>
                  </li>
                </ul>
              </div>
            </div>
          </nav>
        </div>
      </div>
      <style jsx>{stylesheet}</style>
    </nav>
  );
};

Navigation.defaultProps = {
  site: '',
  classes: {},
};

export default Navigation;
